@@ -18,6 +18,10 @@ PIPELINE_DEFAULTS = "pipeline_defaults"
 RUNTIME_IMAGE = "runtime_image"
 ENV_VARIABLES = "env_vars"
 MOUNTED_VOLUMES = "mounted_volumes"
+KUBERNETES_SECRETS = "kubernetes_secrets"
+KUBERNETES_TOLERATIONS = "kubernetes_tolerations"
+KUBERNETES_POD_ANNOTATIONS = "kubernetes_pod_annotations"
 PIPELINE_META_PROPERTIES = ["name", "description", "runtime"]
 # optional static prefix to be used when generating an object name for object storage
 COS_OBJECT_PREFIX = "cos_object_prefix"
+ELYRA_COMPONENT_PROPERTIES = [MOUNTED_VOLUMES, KUBERNETES_TOLERATIONS, KUBERNETES_POD_ANNOTATIONS]
