@@ -25,12 +25,16 @@ from tornado.httpclient import HTTPClientError
 
 from elyra.metadata.metadata import Metadata
 from elyra.metadata.schemaspaces import ComponentCatalogs
+from elyra.pipeline.parser import PipelineParser
+from elyra.pipeline.processor import PipelineProcessorManager
 from elyra.pipeline.runtime_type import RuntimeProcessorType
 from elyra.pipeline.runtime_type import RuntimeTypeResources
+from elyra.pipeline.validation import PipelineValidationManager
+from elyra.pipeline.validation import ValidationResponse
+from elyra.pipeline.validation import ValidationSeverity
 from elyra.tests.pipeline import resources
 from elyra.tests.util.handlers_utils import expected_http_error
 
-
 try:
     import importlib.resources as pkg_resources
 except ImportError:
@@ -42,6 +46,13 @@ COMPONENT_CATALOG_DIRECTORY = os.path.join(jupyter_core.paths.ENV_JUPYTER_PATH[0
 TEST_CATALOG_NAME = "test_handlers_catalog"
 
 
+def _async_return(result):
+    # Helper function to return an arbitrary value when mocking awaits
+    f = asyncio.Future()
+    f.set_result(result)
+    return f
+
+
 def _get_resource_path(filename):
     resource_path = os.path.join(os.path.dirname(__file__), "resources", "components", filename)
     resource_path = os.path.normpath(resource_path)
@@ -87,6 +98,23 @@ async def test_get_components(jp_fetch):
     assert payload == palette
 
 
+async def test_get_components_runtime_name_vs_type(jp_fetch, caplog):
+    # Ensure deprecation warning appears when querying endpoint with shorthand runtime name
+    runtime_name = "kfp"
+    response = await jp_fetch("elyra", "pipeline", "components", runtime_name)
+    assert response.code == 200
+    assert "Deprecation warning: when calling endpoint" in caplog.text
+    caplog.clear()
+
+    # Ensure no deprecation warning appears when using runtime type name. The type
+    # is case-insensitive, e.g., a runtime type can use either lowercase 'local' or
+    # uppercase 'LOCAL'
+    runtime_type = RuntimeProcessorType.LOCAL  # use LOCAL runtime type
+    response = await jp_fetch("elyra", "pipeline", "components", runtime_type.name.lower())  # fetch with 'local'
+    assert response.code == 200
+    assert "Deprecation warning: when calling endpoint" not in caplog.text
+
+
 async def test_get_component_properties_config(jp_fetch):
     # Ensure all valid component_entry properties can be found
     runtime_type = RuntimeProcessorType.LOCAL
@@ -101,7 +129,7 @@ async def test_get_component_properties_config(jp_fetch):
 async def test_get_component_properties_definition(catalog_instance, jp_fetch, caplog):
     # Ensure the definition for a component can be found
     component_url = (
-        "https://raw.githubusercontent.com/elyra-ai/examples/master/component-catalog-connectors/"
+        "https://raw.githubusercontent.com/elyra-ai/examples/main/component-catalog-connectors/"
         "kfp-example-components-connector/kfp_examples_connector/resources/download_data.yaml"
     )
     definition = requests.get(component_url)
@@ -201,5 +229,51 @@ async def test_get_pipeline_properties_definition(jp_fetch):
             {"id": "cos_object_prefix"},
             {"id": "elyra_runtime_image"},
             {"id": "elyra_env_vars"},
+            {"id": "elyra_kubernetes_secrets"},
+            {"id": "elyra_kubernetes_tolerations"},
             {"id": "elyra_mounted_volumes"},
+            {"id": "elyra_kubernetes_pod_annotations"},
         ]
+
+
+async def test_pipeline_success(jp_fetch, monkeypatch):
+    request_body = {"pipeline": "body", "export_format": "py", "export_path": "test.py", "overwrite": True}
+
+    # Create a response that will trigger the valid code path
+    validation_response = ValidationResponse()
+
+    monkeypatch.setattr(PipelineValidationManager, "validate", lambda x, y: _async_return(validation_response))
+    monkeypatch.setattr(PipelineParser, "parse", lambda x, y: "Dummy_Data")
+    monkeypatch.setattr(PipelineProcessorManager, "export", lambda x, y, z, aa, bb: _async_return("test.py"))
+
+    json_body = json.dumps(request_body)
+
+    http_response = await jp_fetch("elyra", "pipeline", "export", body=json_body, method="POST")
+
+    assert http_response.code == 201
+
+
+async def test_pipeline_failure(jp_fetch, monkeypatch):
+    request_body = {"pipeline": "body", "export_format": "py", "export_path": "test.py", "overwrite": True}
+
+    # Create a response that will trigger the fatal code path
+    bad_validation_response = ValidationResponse()
+    bad_validation_response.add_message(severity=ValidationSeverity.Error, message_type="invalidJSON", message="issue")
+
+    monkeypatch.setattr(PipelineValidationManager, "validate", lambda x, y: _async_return(bad_validation_response))
+
+    json_body = json.dumps(request_body)
+
+    # Will raise HTTP error so we need to catch with pytest
+    with pytest.raises(HTTPClientError):
+        await jp_fetch("elyra", "pipeline", "export", body=json_body, method="POST")
+
+
+async def test_validation_handler(jp_fetch, monkeypatch):
+    request_body = {"pipeline": "body", "export_format": "py", "export_path": "test.py", "overwrite": True}
+
+    monkeypatch.setattr(PipelineValidationManager, "validate", lambda x, y: _async_return(ValidationResponse()))
+    json_body = json.dumps(request_body)
+    http_response = await jp_fetch("elyra", "pipeline", "validate", body=json_body, method="POST")
+
+    assert http_response.code == 200
